import Vue from 'vue';
import Router from 'vue-router';
import { Config, Http } from '@zeedhi/core';
import { ZdPage } from '@zeedhi/vue';
import {TekLibAuth, TekLibLocalStorage} from "@zeedhi/tek-lib";
import { ZdFramePage } from "@zeedhi/vuetify";
import Store from './store';

Vue.use(Router);

const router = new Router({
  mode: 'history',
  base: process.env.BASE_URL,
  routes: [
    {
      path: '/',
      name: 'home',
      component: ZdFramePage,
      props: () => ({
        type: 'post',
        params: {
          jsonPath: 'home',
          routePath: true,
        }
      }),
    },
    {
      path: '/modules/:module/:page',
      name: 'microservice',
      component: () => import('./views/Microservice.vue'),
    },
    {
      path: '/auth/login',
      name: 'login',
      component: ZdPage,
      props: () => ({
        path: 'login',
        local: true,
      }),
    },
    {
      path: '*',
      component: ZdPage,
      props: {
        path: 'notfound',
        local: true,
      },
    },
    {
      path: '/chartView',
      name: 'chartView',
     component: ZdFramePage,
      props: () => ({
        type: 'post',
        params: {
          jsonPath: 'chartView',
         local: true,
        }
      }),
    },
    {
      path: '/teste',
      name: 'chartView',
     component: ZdFramePage,
      props: () => ({
        type: 'post',
        params: {
          jsonPath: 'teste',
         local: true,
        }
      }),
    },
    {
      path: '/queryRunner',
      name: 'queryRunner',
     component: ZdFramePage,
      props: () => ({
        type: 'post',
        params: {
          jsonPath: 'queryRunner/queryRunner',
         local: true,
        }
      }),
    },
    {
      path: '/observacao-de-periodo',
      name: 'periodObservation',
     component: ZdFramePage,
      props: () => ({
        type: 'post',
        params: {
          jsonPath: 'periodObservation/periodObservation',
         local: true,
        }
      }),
    },
    {
      path: '/estiloCSS',
      name: 'estiloCSS',
     component: ZdFramePage,
      props: () => ({
        type: 'post',
        params: {
          jsonPath: 'EstiloCSS/estiloCSS',
         local: true,
        }
      }),
    },
    {
      path: '/collector-log',
      name: 'collector-log',
     component: ZdFramePage,
      props: () => ({
        type: 'post',
        params: {
          jsonPath: 'CollectorLog/collectorLog',
         local: true,
        }
      }),
    },
    {
      path: '/colorPalette',
      name: 'colorPalette',
     component: ZdFramePage,
      props: () => ({
        type: 'post',
        params: {
          jsonPath: 'ColorPalette/colorPalette',
         local: true,
        }
      }),
    },
    {
      path: '/managementStructures',
      name: 'managementStructures',
     component: ZdFramePage,
      props: () => ({
        type: 'post',
        params: {
          jsonPath: 'ManagementStructures/managementStructures',
         local: true,
        }
      }),
    },
    {
      path: '/periods',
      name: 'periods',
     component: ZdFramePage,
      props: () => ({
        type: 'post',
        params: {
          jsonPath: 'periods/periods',
         local: true,
        }
      }),
    },
    {
      path: '/menuConfiguration',
      name: 'menuConfiguration',
     component: ZdFramePage,
      props: () => ({
        type: 'post',
        params: {
          jsonPath: 'menuConfiguration/menuConfiguration',
         local: true,
        }
      }),
    },
    {
      path: '/dashboardConfiguration',
      name: 'dashboardConfiguration',
     component: ZdFramePage,
      props: () => ({
        type: 'post',
        params: {
          jsonPath: 'dashboardConfiguration/dashboardConfiguration',
         local: true,
        }
      }),
    },
    {
      path: '/conexaoBD',
      name: 'dbConnection',
     component: ZdFramePage,
      props: () => ({
        type: 'post',
        params: {
          jsonPath: 'dbConnection/dbConnection',
         local: true,
        }
      }),
    },
    {
      path: '/defaultColumns',
      name: 'defaultColumns',
     component: ZdFramePage,
      props: () => ({
        type: 'post',
        params: {
          jsonPath: 'defaultColumns/defaultColumns',
         local: true,
        }
      }),
    },
    {
      path: '/indicatorsDatabase',
      name: 'indicatorsDatabase',
     component: ZdFramePage,
      props: () => ({
        type: 'post',
        params: {
          jsonPath: 'indicatorsDatabase/indicatorsDatabase',
         local: true,
        }
      }),
    },
    {
      path: '/defaultRelatedStructures',
      name: 'relatedStructures',
     component: ZdFramePage,
      props: () => ({
        type: 'post',
        params: {
          jsonPath: 'relatedStructures/relatedStructures',
         local: true,
        }
      }),
    },
    {
      path: '/management',
      name: 'management',
     component: ZdFramePage,
      props: () => ({
        type: 'post',
        params: {
          jsonPath: 'management/management',
         local: true,
        }
      }),
    },
    {
      path: '/dataSource',
      name: 'dataSource',
     component: ZdFramePage,
      props: () => ({
        type: 'post',
        params: {
          jsonPath: 'dataSource/dataSource',
         local: true,
        }
      }),
    },
    {
      path: '/changeClient',
      name: 'changeClient',
     component: ZdFramePage,
      props: () => ({
        type: 'post',
        params: {
          jsonPath: 'changeClient/changeClient',
         local: true,
        }
      }),
    },
    {
      path: '/indicators',
      name: 'indicators',
     component: ZdFramePage,
      props: () => ({
        type: 'post',
        params: {
          jsonPath: 'indicators/indicators',
         local: true,
        }
      }),
    },
  ],
});

const isOpeningNewModule = function isOpeningNewModule(to: any, from: any) {
    const isFromProduct = (to.name === 'microservice' && from.name !== 'microservice');
    // eslint-disable-next-line max-len
    const isFromAnotherModule = ((to.name === 'microservice' && from.name === 'microservice') && to.path.split('/')[2] !== from.path.split('/')[2]);
    const isNotLoginRoute = (to.fullPath !== Config.env.modules.login.routePath);
    return ((isFromProduct || isFromAnotherModule) && isNotLoginRoute);
};

// eslint-disable-next-line max-len
const callLibStartSessionFromModule = async function callLibStartSessionFromModule(to: any) {
    const data = {
        USER: localStorage.getItem('LOGIN_USER'),
        LOGIN_LANGUAGE: localStorage.getItem('LOGIN_LAGUAGE'),
        LOGIN_TOKEN: localStorage.getItem('LOGIN_TOKEN'),
    };
    await Http.post(`${Config.env.modules[to.path.split('/')[2]].endPoint}/lib_startSession`, data);
};

router.beforeEach(async (to, from, next) => {
  if (isOpeningNewModule(to, from)) {
    await callLibStartSessionFromModule(to);
  }

  TekLibLocalStorage.setItem('IS_NEXT', true);
  TekLibAuth.setInitialData(to.path, Config.env.loginRoutePath);
  if (to.path !== Config.env.loginRoutePath && !localStorage.getItem('LOGIN_TOKEN')) {
    next(Config.env.loginRoutePath);
  } else if (to.path === Config.env.loginRoutePath && localStorage.getItem('LOGIN_TOKEN')) {
    next(Config.env.baseUrl);
  } else {
    next();
  }
});

router.afterEach((to, from) => {
  const htmlElement = document.getElementsByTagName('html')[0];
  if (to.name === 'microservice') {
    htmlElement.setAttribute('microservice', '');
    Store.commit('setRouterParams', to.params);
    const frame = (document.getElementById('microservice-frame') as HTMLIFrameElement);
    if (frame && frame.contentWindow && to.path.split('/')[2] === from.path.split('/')[2]) {
      frame.contentWindow.postMessage({
        type: 'microservice-route-change',
        routerParams: to.params,
      }, `${Config.env.modules[to.path.split('/')[2]].baseUrl}`);
    }
    window.document.title = `${Config.env.product.name} - ${to.params.page}`;
  } else {
    htmlElement.removeAttribute('microservice');
    window.document.title = Config.env.product.name;
  }

  if (to.name === 'login') {
    htmlElement.setAttribute('login', '');
  } else {
    htmlElement.removeAttribute('login');
  }
});

export default router;
